@@ -71,7 +71,7 @@ const int UNLEN = 256;
 #endif
 
 #ifndef DISABLE_GUI
-#ifdef Q_WS_X11
+#if defined(Q_WS_X11) && defined(QT_DBUS_LIB)
 #include <QDBusInterface>
 #include <QDBusMessage>
 #endif
@@ -79,13 +79,15 @@ const int UNLEN = 256;
 
 using namespace libtorrent;
 
+const int MAX_FILENAME_LENGTH = 255;
+
 static struct { const char *source; const char *comment; } units[] = {
-    QT_TRANSLATE_NOOP3("misc", "B", "bytes"),
-    QT_TRANSLATE_NOOP3("misc", "KiB", "kibibytes (1024 bytes)"),
-    QT_TRANSLATE_NOOP3("misc", "MiB", "mebibytes (1024 kibibytes)"),
-    QT_TRANSLATE_NOOP3("misc", "GiB", "gibibytes (1024 mibibytes)"),
-    QT_TRANSLATE_NOOP3("misc", "TiB", "tebibytes (1024 gibibytes)")
-    };
+  QT_TRANSLATE_NOOP3("misc", "B", "bytes"),
+  QT_TRANSLATE_NOOP3("misc", "KiB", "kibibytes (1024 bytes)"),
+  QT_TRANSLATE_NOOP3("misc", "MiB", "mebibytes (1024 kibibytes)"),
+  QT_TRANSLATE_NOOP3("misc", "GiB", "gibibytes (1024 mibibytes)"),
+  QT_TRANSLATE_NOOP3("misc", "TiB", "tebibytes (1024 gibibytes)")
+};
 
 QString misc::QDesktopServicesDataLocation() {
 #ifdef Q_WS_WIN
@@ -206,14 +208,35 @@ long long misc::freeDiskSpaceOnPath(QString path) {
 
 #ifndef DISABLE_GUI
 void misc::shutdownComputer(bool sleep) {
-#ifdef Q_WS_X11
-  // Use dbus to power off the system
-  // dbus-send --print-reply --system --dest=org.freedesktop.Hal /org/freedesktop/Hal/devices/computer org.freedesktop.Hal.Device.SystemPowerManagement.Shutdown
-  QDBusInterface computer("org.freedesktop.Hal", "/org/freedesktop/Hal/devices/computer", "org.freedesktop.Hal.Device.SystemPowerManagement", QDBusConnection::systemBus());
-  if(sleep)
-    computer.call("Suspend", 5);
-  else
-    computer.call("Shutdown");
+#if defined(Q_WS_X11) && defined(QT_DBUS_LIB)
+  // Use dbus to power off / suspend the system
+  if(sleep) {
+    // Recent systems use UPower
+    QDBusInterface upowerIface("org.freedesktop.UPower", "/org/freedesktop/UPower",
+                               "org.freedesktop.UPower", QDBusConnection::systemBus());
+    if(upowerIface.isValid()) {
+      upowerIface.call("Suspend");
+      return;
+    }
+    // HAL (older systems)
+    QDBusInterface halIface("org.freedesktop.Hal", "/org/freedesktop/Hal/devices/computer",
+                            "org.freedesktop.Hal.Device.SystemPowerManagement",
+                            QDBusConnection::systemBus());
+    halIface.call("Suspend", 5);
+  } else {
+    // Recent systems use ConsoleKit
+    QDBusInterface consolekitIface("org.freedesktop.ConsoleKit", "/org/freedesktop/ConsoleKit/Manager",
+                                   "org.freedesktop.ConsoleKit.Manager", QDBusConnection::systemBus());
+    if(consolekitIface.isValid()) {
+      consolekitIface.call("Stop");
+      return;
+    }
+    // HAL (older systems)
+    QDBusInterface halIface("org.freedesktop.Hal", "/org/freedesktop/Hal/devices/computer",
+                            "org.freedesktop.Hal.Device.SystemPowerManagement",
+                            QDBusConnection::systemBus());
+    halIface.call("Shutdown");
+  }
 #endif
 #ifdef Q_WS_MAC
   AEEventID EventToSend;
@@ -291,34 +314,64 @@ void misc::shutdownComputer(bool sleep) {
 }
 #endif // DISABLE_GUI
 
+QString misc::fixFileNames(QString path) {
+  //qDebug() << Q_FUNC_INFO << path;
+  path.replace("\\", "/");
+  QStringList parts = path.split("/", QString::SkipEmptyParts);
+  if(parts.isEmpty()) return path;
+  QString last_part = parts.takeLast();
+  QList<QString>::iterator it;
+  for(it = parts.begin(); it != parts.end(); it++) {
+    QByteArray raw_filename = it->toLocal8Bit();
+    // Make sure the filename is not too long
+    if(raw_filename.size() > MAX_FILENAME_LENGTH) {
+      qDebug() << "Folder" << *it << "was cut because it was too long";
+      raw_filename.resize(MAX_FILENAME_LENGTH);
+      *it = QString::fromLocal8Bit(raw_filename.constData());
+      qDebug() << "New folder name is" << *it;
+      Q_ASSERT(it->length() == MAX_FILENAME_LENGTH);
+    }
+  }
+  // Fix the last part (file name)
+  QByteArray raw_lastPart = last_part.toLocal8Bit();
+  qDebug() << "Last part length:" << raw_lastPart.length();
+  if(raw_lastPart.length() > MAX_FILENAME_LENGTH) {
+    qDebug() << "Filename" << last_part << "was cut because it was too long";
+    // Shorten the name, keep the file extension
+    int point_index = raw_lastPart.lastIndexOf(".");
+    QByteArray extension = "";
+    if(point_index >= 0) {
+      extension = raw_lastPart.mid(point_index);
+      raw_lastPart = raw_lastPart.left(point_index);
+    }
+    raw_lastPart = raw_lastPart.left(MAX_FILENAME_LENGTH-extension.length()) + extension;
+    Q_ASSERT(raw_lastPart.length() == MAX_FILENAME_LENGTH);
+    last_part = QString::fromLocal8Bit(raw_lastPart.constData());
+    qDebug() << "New file name is" << last_part;
+  }
+  parts << last_part;
+  return parts.join("/");
+}
+
 QString misc::truncateRootFolder(boost::intrusive_ptr<torrent_info> t) {
-#if LIBTORRENT_VERSION_MINOR >= 16
-  file_storage fs = t->files();
-#endif
   if(t->num_files() == 1) {
     // Single file torrent
-    // Remove possible subfolders
-#if LIBTORRENT_VERSION_MINOR >= 16
-    QString path = toQStringU(fs.file_path(t->file_at(0)));
-#else
     QString path = QString::fromUtf8(t->file_at(0).path.string().c_str());
-#endif
-    t->rename_file(0, fileName(path).toUtf8().data());
-    return QString::null;
+    // Remove possible subfolders
+    path = fixFileNames(fileName(path));
+    t->rename_file(0, path.toUtf8().data());
+    return QString();
   }
   QString root_folder;
   int i = 0;
   for(torrent_info::file_iterator it = t->begin_files(); it < t->end_files(); it++) {
-#if LIBTORRENT_VERSION_MINOR >= 16
-    QString path = toQStringU(fs.file_path(*it));
-#else
     QString path = QString::fromUtf8(it->path.string().c_str());
-#endif
     QStringList path_parts = path.split("/", QString::SkipEmptyParts);
     if(path_parts.size() > 1) {
       root_folder = path_parts.takeFirst();
-      t->rename_file(i, path_parts.join("/").toUtf8().data());
     }
+    path = fixFileNames(path_parts.join("/"));
+    t->rename_file(i, path.toUtf8().data());
     ++i;
   }
   return root_folder;
@@ -326,33 +379,24 @@ QString misc::truncateRootFolder(boost::intrusive_ptr<torrent_info> t) {
 
 QString misc::truncateRootFolder(libtorrent::torrent_handle h) {
   torrent_info t = h.get_torrent_info();
-#if LIBTORRENT_VERSION_MINOR >= 16
-  file_storage fs = t.files();
-#endif
   if(t.num_files() == 1) {
     // Single file torrent
     // Remove possible subfolders
-#if LIBTORRENT_VERSION_MINOR >= 16
-    QString path = misc::toQStringU(fs.file_path(t.file_at(0)));
-#else
     QString path = QString::fromUtf8(t.file_at(0).path.string().c_str());
-#endif
-    t.rename_file(0, fileName(path).toUtf8().data());
-    return QString::null;
+    path = fixFileNames(fileName(path));
+    t.rename_file(0, path.toUtf8().data());
+    return QString();
   }
   QString root_folder;
   int i = 0;
   for(torrent_info::file_iterator it = t.begin_files(); it < t.end_files(); it++) {
-#if LIBTORRENT_VERSION_MINOR >= 16
-    QString path = toQStringU(fs.file_path(*it));
-#else
     QString path = QString::fromUtf8(it->path.string().c_str());
-#endif
     QStringList path_parts = path.split("/", QString::SkipEmptyParts);
     if(path_parts.size() > 1) {
       root_folder = path_parts.takeFirst();
-      h.rename_file(i, path_parts.join("/").toUtf8().data());
     }
+    path = fixFileNames(path_parts.join("/"));
+    h.rename_file(i, path.toUtf8().data());
     ++i;
   }
   return root_folder;
@@ -809,3 +853,63 @@ bool misc::removeEmptyFolder(const QString &dirpath)
   }
   return false;
 }
+
+QString misc::parseHtmlLinks(const QString &raw_text)
+{
+  QString result = raw_text;
+  QRegExp reURL("(\\s|^)"                                     //start with whitespace or beginning of line
+                "("
+                "("                                      //case 1 -- URL with scheme
+                "(http(s?))\\://"                    //start with scheme
+                "([a-zA-Z0-9_-]+\\.)+"               //  domainpart.  at least one of these must exist
+                "([a-zA-Z0-9\\?%=&/_\\.:#;-]+)"      //  everything to 1st non-URI char, must be at least one char after the previous dot (cannot use ".*" because it can be too greedy)
+                ")"
+                "|"
+                "("                                     //case 2a -- no scheme, contains common TLD  example.com
+                "([a-zA-Z0-9_-]+\\.)+"              //  domainpart.  at least one of these must exist
+                "(?="                               //  must be followed by TLD
+                "AERO|aero|"                  //N.B. assertions are non-capturing
+                "ARPA|arpa|"
+                "ASIA|asia|"
+                "BIZ|biz|"
+                "CAT|cat|"
+                "COM|com|"
+                "COOP|coop|"
+                "EDU|edu|"
+                "GOV|gov|"
+                "INFO|info|"
+                "INT|int|"
+                "JOBS|jobs|"
+                "MIL|mil|"
+                "MOBI|mobi|"
+                "MUSEUM|museum|"
+                "NAME|name|"
+                "NET|net|"
+                "ORG|org|"
+                "PRO|pro|"
+                "RO|ro|"
+                "RU|ru|"
+                "TEL|tel|"
+                "TRAVEL|travel"
+                ")"
+                "([a-zA-Z0-9\\?%=&/_\\.:#;-]+)"     //  everything to 1st non-URI char, must be at least one char after the previous dot (cannot use ".*" because it can be too greedy)
+                ")"
+                "|"
+                "("                                     // case 2b no scheme, no TLD, must have at least 2 aphanum strings plus uncommon TLD string  --> del.icio.us
+                "([a-zA-Z0-9_-]+\\.){2,}"           //2 or more domainpart.   --> del.icio.
+                "[a-zA-Z]{2,}"                      //one ab  (2 char or longer) --> us
+                "([a-zA-Z0-9\\?%=&/_\\.:#;-]*)"     // everything to 1st non-URI char, maybe nothing  in case of del.icio.us/path
+                ")"
+                ")"
+                );
+
+
+  // Capture links
+  result.replace(reURL, "\\1<a href=\"\\2\">\\2</a>");
+
+  // Capture links without scheme
+  QRegExp reNoScheme("<a\\s+href=\"(?!http(s?))([a-zA-Z0-9\\?%=&/_\\.-:#]+)\\s*\">");
+  result.replace(reNoScheme, "<a href=\"http://\\1\">");
+
+  return result;
+}
