@@ -123,12 +123,15 @@ public:
     return MyFile.remove();
   }
 
+  static QString parseHtmlLinks(const QString &raw_text);
+
   static bool removeEmptyFolder(const QString &dirpath);
 
   static quint64 computePathSize(QString path);
 
   static QString truncateRootFolder(boost::intrusive_ptr<libtorrent::torrent_info> t);
   static QString truncateRootFolder(libtorrent::torrent_handle h);
+  static QString fixFileNames(QString path);
 
   static QString updateLabelInSavePath(QString defaultSavePath, QString save_path, const QString &old_label, const QString &new_label);
 
