@@ -99,7 +99,11 @@ SearchEngine::SearchEngine(MainWindow *parent) : QWidget(parent), mp_mainWindow(
   connect(searchTimeout, SIGNAL(timeout()), this, SLOT(on_search_button_clicked()));
   // Update nova.py search plugin if necessary
   updateNova();
-  supported_engines = new SupportedEngines();
+  supported_engines = new SupportedEngines(
+      #ifdef Q_WS_WIN
+        has_python
+      #endif
+        );
   // Fill in category combobox
   fillCatCombobox();
   connect(search_pattern, SIGNAL(customContextMenuRequested(QPoint)), this, SLOT(displayPatternContextMenu(QPoint)));
@@ -137,10 +141,10 @@ bool SearchEngine::addPythonPathToEnv() {
 void SearchEngine::installPython() {
   setCursor(QCursor(Qt::WaitCursor));
   // Download python
-  downloadThread *pydownloader = new downloadThread(this);
+  DownloadThread *pydownloader = new DownloadThread(this);
   connect(pydownloader, SIGNAL(downloadFinished(QString,QString)), this, SLOT(pythonDownloadSuccess(QString,QString)));
   connect(pydownloader, SIGNAL(downloadFailure(QString,QString)), this, SLOT(pythonDownloadFailure(QString,QString)));
-  pydownloader->downloadUrl("http://python.org/ftp/python/2.6.5/python-2.6.5.msi");
+  pydownloader->downloadUrl("http://python.org/ftp/python/2.7.1/python-2.7.1.msi");
 }
 
 void SearchEngine::pythonDownloadSuccess(QString url, QString file_path) {
@@ -725,7 +729,7 @@ void SearchEngine::on_goToDescBtn_clicked()
       QSortFilterProxyModel* model = all_tab.at(tabWidget->currentIndex())->getCurrentSearchListProxy();
       const QString desc_url = model->data(model->index(index.row(), DESC_LINK)).toString();
       if(!desc_url.isEmpty())
-        QDesktopServices::openUrl(QUrl(desc_url));
+        QDesktopServices::openUrl(QUrl::fromEncoded(desc_url.toUtf8()));
     }
   }
 }
