@@ -51,6 +51,7 @@
 #include "transferlistdelegate.h"
 #include "previewselect.h"
 #include "speedlimitdlg.h"
+#include "updownratiodlg.h"
 #include "options_imp.h"
 #include "mainwindow.h"
 #include "preferences.h"
@@ -128,6 +129,7 @@ TransferListWidget::TransferListWidget(QWidget *parent, MainWindow *main_window,
 }
 
 TransferListWidget::~TransferListWidget() {
+  qDebug() << Q_FUNC_INFO << "ENTER";
   // Save settings
   saveSettings();
   // Clean up
@@ -136,6 +138,7 @@ TransferListWidget::~TransferListWidget() {
   delete nameFilterModel;
   delete listModel;
   delete listDelegate;
+  qDebug() << Q_FUNC_INFO << "EXIT";
 }
 
 TorrentModel* TransferListWidget::getSourceModel() const {
@@ -281,28 +284,29 @@ void TransferListWidget::pauseVisibleTorrents() {
 void TransferListWidget::deleteSelectedTorrents() {
   if(main_window->getCurrentTabWidget() != this) return;
   const QStringList& hashes = getSelectedTorrentsHashes();
-  if(!hashes.empty()) {
-    bool delete_local_files = false;
-    if(DeletionConfirmationDlg::askForDeletionConfirmation(&delete_local_files)) {
-      foreach(const QString &hash, hashes) {
-        BTSession->deleteTorrent(hash, delete_local_files);
-      }
-    }
+  if(hashes.empty()) return;
+  bool delete_local_files = false;
+  if(Preferences().confirmTorrentDeletion() &&
+      !DeletionConfirmationDlg::askForDeletionConfirmation(&delete_local_files))
+    return;
+  foreach(const QString &hash, hashes) {
+    BTSession->deleteTorrent(hash, delete_local_files);
   }
 }
 
 void TransferListWidget::deleteVisibleTorrents() {
   if(nameFilterModel->rowCount() <= 0) return;
   bool delete_local_files = false;
-  if(DeletionConfirmationDlg::askForDeletionConfirmation(&delete_local_files)) {
-    QStringList hashes;
-    for(int i=0; i<nameFilterModel->rowCount(); ++i) {
-      const int row = mapToSource(nameFilterModel->index(i, 0)).row();
-      hashes << getHashFromRow(row);
-    }
-    foreach(const QString &hash, hashes) {
-      BTSession->deleteTorrent(hash, delete_local_files);
-    }
+  if(Preferences().confirmTorrentDeletion() &&
+      !DeletionConfirmationDlg::askForDeletionConfirmation(&delete_local_files))
+    return;
+  QStringList hashes;
+  for(int i=0; i<nameFilterModel->rowCount(); ++i) {
+    const int row = mapToSource(nameFilterModel->index(i, 0)).row();
+    hashes << getHashFromRow(row);
+  }
+  foreach(const QString &hash, hashes) {
+    BTSession->deleteTorrent(hash, delete_local_files);
   }
 }
 
@@ -484,6 +488,29 @@ void TransferListWidget::setUpLimitSelectedTorrents() {
   }
 }
 
+void TransferListWidget::setMaxRatioSelectedTorrents() {
+  const QStringList hashes = getSelectedTorrentsHashes();
+  if (hashes.isEmpty())
+    return;
+  bool useGlobalValue;
+  qreal currentMaxRatio;
+  if (hashes.count() == 1) {
+    currentMaxRatio = BTSession->getMaxRatioPerTorrent(hashes.first(), &useGlobalValue);
+  } else {
+    useGlobalValue = true;
+    currentMaxRatio = BTSession->getGlobalMaxRatio();
+  }
+  UpDownRatioDlg dlg(useGlobalValue, currentMaxRatio, QBtSession::MAX_RATIO, this);
+  if (dlg.exec() != QDialog::Accepted)
+    return;
+  foreach (const QString &hash, hashes) {
+    if (dlg.useDefault())
+      BTSession->removeRatioPerTorrent(hash);
+    else
+      BTSession->setMaxRatioPerTorrent(hash, dlg.ratio());
+  }
+}
+
 void TransferListWidget::recheckSelectedTorrents() {
   const QStringList hashes = getSelectedTorrentsHashes();
   foreach(const QString &hash, hashes) {
@@ -622,6 +649,8 @@ void TransferListWidget::displayListMenu(const QPoint&) {
   connect(&actionDelete, SIGNAL(triggered()), this, SLOT(deleteSelectedTorrents()));
   QAction actionPreview_file(IconProvider::instance()->getIcon("view-preview"), tr("Preview file..."), 0);
   connect(&actionPreview_file, SIGNAL(triggered()), this, SLOT(previewSelectedTorrents()));
+  QAction actionSet_max_ratio(QIcon(QString::fromUtf8(":/Icons/skin/ratio.png")), tr("Limit share ratio..."), 0);
+  connect(&actionSet_max_ratio, SIGNAL(triggered()), this, SLOT(setMaxRatioSelectedTorrents()));
   QAction actionSet_upload_limit(QIcon(QString::fromUtf8(":/Icons/skin/seeding.png")), tr("Limit upload rate..."), 0);
   connect(&actionSet_upload_limit, SIGNAL(triggered()), this, SLOT(setUpLimitSelectedTorrents()));
   QAction actionSet_download_limit(QIcon(QString::fromUtf8(":/Icons/skin/download.png")), tr("Limit download rate..."), 0);
@@ -744,6 +773,7 @@ void TransferListWidget::displayListMenu(const QPoint&) {
   listMenu.addSeparator();
   if(one_not_seed)
     listMenu.addAction(&actionSet_download_limit);
+  listMenu.addAction(&actionSet_max_ratio);
   listMenu.addAction(&actionSet_upload_limit);
 #if LIBTORRENT_VERSION_MINOR > 14
   if(!one_not_seed && all_same_super_seeding && one_has_metadata) {
